# CHANGELOG

v5.2.2
    - Improved documentation and removed unecessary check

v5.2.1:
  - 2bb7b05: Added negative sign check

v5.2:
  - 6f9d124: Implemented log and improved simplify
  - b773e7a: Added named export to TS definition
  - 70304f9: Fixed merge conflict
  - 3b940d3: Implemented other comparing functions
  - 10acdfc: Update README.md
  - ba41d00: Update README.md
  - 73ded97: Update README.md
  - acabc39: Fixed param parsing

v5.0.5:
  - 2c9d4c2: Improved roundTo() and param parser

v5.0.4:
  - 39e61e7: Fixed bignum param passing

v5.0.3:
  - 7d9a3ec: Upgraded bundler for code quality

v5.0.2:
  - c64b1d6: fixed esm export

v5.0.1:
  - e440f9c: Fixed CJS export
  - 9bbdd29: Fixed CJS export

v5.0.0:
  - ac7cd06: Fixed readme
  - 33cc9e5: Added crude build
  - 1adcc76: Release breaking v5.0. Fraction.js now builds on BigInt. The API stays the same as v4, except that the object attributes `n`, `d`, and `s`, are not Number but BigInt and may break code that directly accesses these attributes.